@@ -5,7 +5,7 @@ import re
 from skimage import io
 from skimage.color import rgb2gray
 import pandas as pd
-from skimage.external.tifffile import imsave
+from tifffile import imsave
 import numpy as np
 import random
 import subprocess
