@@ -96,8 +96,9 @@ var map%d = initializeMap(elementid="map%d", zoomControl=false, zoomSnap=0.5, zo
 """ % (c["id"], c["id"], c["maxBound"])
 
 	line1 = """var t_panel_%d = new PanelPhysicalSimple({name:"physical.dot", map:map%d, mapid:%d, annot_set:a_set,
+file_gene_map:"%s", dir_gene_expression:"%s", file_gene_list:"%s", 
 file_simple:"%s", load_simple:true, default_annot:"%s", load_annot:true});
-""" % (c["id"], c["id"], c["id"], c["file_simple"], c["annot"])
+""" % (c["id"], c["id"], c["id"], c["gene_map"], c["dir_gene_expression"], c["gene_list"], c["file_simple"], c["annot"])
 	return [header, line1]
 
 def generate_annot_set(c):
